trustmapping

package
v0.18.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Package trustmapping provides the service.module.grpc.trustmapping module: a gRPC service module that registers the kms.api.cmk.sessionmanager.trustmapping.v1.Service proto onto a grpc.ServiceRegistrar supplied by app.module.grpcserver.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Module

type Module struct {
	Mod   string `yaml:"module"`
	Trust string `yaml:"trust" default:"trust.module.oidc" dep:"sessionmanager.Trust"`
	// contains filtered or unexported fields
}

Module is the service.module.grpc.trustmapping module. It owns a Server that implements the trustmapping proto and resolves its single dependency (a sessionmanager.Trust implementation) by ID via ctx.GetModule.

func (*Module) Module

func (m *Module) Module() sessionmanager.ModuleInfo

func (*Module) Provision

func (m *Module) Provision(ctx *sessionmanager.Context) error

func (*Module) Register

func (m *Module) Register(s grpc.ServiceRegistrar)

type Server

type Server struct {
	trustmappingv1.UnimplementedServiceServer
	// contains filtered or unexported fields
}

func NewServer

func NewServer(trust sessionmanager.Trust) *Server

func (*Server) BlockTrustMapping

BlockTrustMapping blocks the trust for the specified tenant. It calls the underlying service to set the trust as blocked. Returns a response containing an optional error message if blocking fails.

func (*Server) RemoveTrustMapping

RemoveTrustMapping removes the trust configuration for the tenant. It calls the underlying service to remove the trust. Returns a respose containing an optional error message if removing fails.

func (*Server) UnblockTrustMapping

UnblockTrustMapping unblocks the trust for the specified tenant. It calls the underlying service to set the trust as unblocked. Returns a response containing an optional error message if unblocking fails.

Jump to